@@ -1,4 +1,4 @@
-// $Id: exerb.cpp,v 1.63 2002/11/27 07:17:50 yuya Exp $
+// $Id: exerb.cpp,v 1.65 2002/12/25 06:52:14 yuya Exp $
 
 ////////////////////////////////////////////////////////////////////////////////
 
@@ -65,7 +65,7 @@ static bool  ExSetup(void);
 static void  ExSetupTable(PEXERB_ARCHIVE_HEADER pArchive);
 static void  ExSetupKcode(PEXERB_ARCHIVE_HEADER pArchive);
 static int   ExExecute(void);
-#ifdef RUBY17
+#ifdef RUBY18
 static VALUE ExExecuteFirstScript(VALUE data);
 #else
 static VALUE ExExecuteFirstScript(void);
@@ -90,8 +90,8 @@ static void  ExReplaceImportTable(DWORD dwOffset);
 static void  ExDllWriteToFile(DWORD dwOffset, DWORD dwSize, char *pszFilePath);
 static HMODULE ExLoadDll(char *pszFilePath, VALUE vFileName);
 static VALUE ExGetInitFunctionName(VALUE vFileName);
-static VALUE ExRequireDll(VALUE vFileName, DWORD dwID);
-static VALUE ExRequireScript(VALUE vFileName, DWORD dwID);
+static bool  ExRequireDll(VALUE vFileName, DWORD dwID);
+static bool  ExRequireScript(VALUE vFileName, DWORD dwID);
 static void  ExGetSelfFilePath(LPSTR pszBuffer, UINT uiBufferSize);
 static void  ExGetSelfFileName(LPSTR pszBuffer, UINT uiBufferSize);
 static VALUE ExEvalString(VALUE vString, VALUE vFileName);
@@ -328,7 +328,7 @@ ExExecute(void)
 }
 
 static VALUE
-#ifdef RUBY17
+#ifdef RUBY18
 ExExecuteFirstScript(VALUE data)
 #else
 ExExecuteFirstScript(void)
@@ -655,7 +655,7 @@ ExReplaceImportTable(DWORD dwOffset)
 	char szSelfFileName[MAX_PATH] = "";
 	::ExGetSelfFileName(szSelfFileName, sizeof(szSelfFileName));
 
-#ifdef RUBY17
+#ifdef RUBY18
 	::ExReplaceImportDllName(dwDosHeader, dwImportTableDelta, &dwNamePoolAddress, &dwNamePoolSize, pDescriptor, "msvcrt-ruby17.dll",  szSelfFileName);
 	::ExReplaceImportDllName(dwDosHeader, dwImportTableDelta, &dwNamePoolAddress, &dwNamePoolSize, pDescriptor, "cygwin-ruby17.dll",  szSelfFileName);
 #else
@@ -736,7 +736,7 @@ ExGetInitFunctionName(VALUE vFileName)
 	return vFunctionName;
 }
 
-static VALUE
+static bool
 ExRequireDll(VALUE vFileName, DWORD dwID)
 {
 	const DWORD dwOffset = g_DllOffsetTable[dwID];
@@ -766,16 +766,16 @@ ExRequireDll(VALUE vFileName, DWORD dwID)
 				::strcpy(g_szPhiSoFileName, pszFileName);
 			}
 
-			return Qtrue;
+			return true;
 		} else {
-			return Qfalse;
+			return false;
 		}
 	} else {
-		return Qfalse;
+		return false;
 	}
 }
 
-static VALUE
+static bool
 ExRequireScript(VALUE vFileName, DWORD dwID)
 {
 	const DWORD dwOffset = g_ScriptOffsetTable[dwID];
@@ -784,10 +784,10 @@ ExRequireScript(VALUE vFileName, DWORD dwID)
 	if ( dwOffset && dwSize ) {
 		VALUE vScript = ::rb_str_new((char*)dwOffset, dwSize);
 		::ExEvalString(vScript, vFileName);
-		return Qtrue;
+		return true;
 	} else {
 		::ExRaiseLoadError(IDS_CANNOT_EXECUTE_SCRIPT);
-		return Qfalse;
+		return false;
 	}
 }
 
